@@ -134,29 +134,29 @@ class Pack(object):
                 temp.move(x,y,0)
                 upper.add(temp)
             
-        bol = int(self.xsize / 20.0)
-        bol_width = 1.0
-            # 0.5 seemed to allow shifting on a sop flute
-        bol_height = 1.0 
-            # 0.5 was too low, middle piece tore loose in final pass of
-            # contour finishing (x-scan of horizontal-like surfaces)
-        xmins = [ x for x,y,packable in self.items ]
-        xmaxs = [ x+packable.extent.xmax for x,y,packable in self.items ]
-        margin = bol_width+bit_diameter+0.25
-        for i in range(bol):
-            pos = (i+0.5)*xsize/bol
-            
-            if any( pos-margin <= item <= pos+bol_width for item in xmins ) or \
-               any( pos-bol_width <= item <= pos+margin for item in xmins ):
-                continue
-            
-            upper.add(shape.block(
-                pos-bol_width*0.5, pos+bol_width*0.5,
-                0,ysize,
-                #-bit_diameter*0.6, bol_height,
-                0,bol_height,
-            ))     
-        
+        #bol = int(self.xsize / 20.0)
+        #bol_width = 1.0
+        #    # 0.5 seemed to allow shifting on a sop flute
+        #bol_height = 1.0 
+        #    # 0.5 was too low, middle piece tore loose in final pass of
+        #    # contour finishing (x-scan of horizontal-like surfaces)
+        #xmins = [ x for x,y,packable in self.items ]
+        #xmaxs = [ x+packable.extent.xmax for x,y,packable in self.items ]
+        #margin = bol_width+bit_diameter+0.25
+        #for i in range(bol):
+        #    pos = (i+0.5)*xsize/bol
+        #    
+        #    if any( pos-margin <= item <= pos+bol_width for item in xmins ) or \
+        #       any( pos-bol_width <= item <= pos+margin for item in xmins ):
+        #        continue
+        #    
+        #    upper.add(shape.block(
+        #        pos-bol_width*0.5, pos+bol_width*0.5,
+        #        0,ysize,
+        #        #-bit_diameter*0.6, bol_height,
+        #        0,bol_height,
+        #    ))     
+        #
         
         print 'Underside'
         
@@ -326,9 +326,8 @@ def pack(template, packables, aspect_goal=1.0):
     for y in xrange(int(template.ysize/step)):
         for x in xrange(int(template.xsize/step)):
             points.append((x*step,y*step))
-    points.sort(key=lambda item: (-item[1],-item[0]))
     
-    todo = sorted(packables, key=lambda item: item[0].extent.xmax)
+    todo = list(packables)
     while todo:
         try:
             queue = [
@@ -405,7 +404,7 @@ def cut_and_pack(outer, bore, top_fractions, bottom_fractions, xsize, ysize, zsi
     print 'Packing'
 
     template = mill_template(xsize + pad*2, ysize + pad*2, zsize, dilation)
-    packs = pack(template, packables, float(ysize)/xsize)
+    packs = pack(template, packables, 0.5*float(ysize)/xsize)
     for item in packs:
         mill_squish(item)
     
